#!/usr/bin/python
# -*- coding: UTF-8 -*-
"""
@author:zhaojiajun
@file:__init__.py.py
@time:2022/07/13
"""

__all__ = ['main', 'db']

if __name__ == '__main__':
    pass
